package com.nisum.mongodb.controller;

import com.nisum.mongodb.model.User;
import com.nisum.mongodb.repository.UserRepository;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping(value = "/user")
@Slf4j
public class UserController {

    @GetMapping(value = "/health")
    public String health() {
       return "OK";
    }
    @Autowired
    private UserRepository userRepository;
    @GetMapping(value = "allUsers")
    public List<User> getAllUsers() {
        log.info("Getting all users.");
        return userRepository.findAll();
    }
    @GetMapping(value = "/{userId}")
    public Optional<User> getUser(@PathVariable String userId) {
        log.info("Getting user with ID: {}.", userId);
        return userRepository.findById(userId);
    }
    @PostMapping(value = "/create")
    public User addNewUsers(@RequestBody User user) {
        log.info("Saving user.");
        user.setCreationDate(new Date());
        return userRepository.save(user);
    }
    @GetMapping(value = "/settings/{userId}")
    public Object getAllUserSettings(@PathVariable String userId) {
        Optional<User> user = userRepository.findById(userId);

        if(user.isPresent()){
            return user.get().getUserSettings();
        }else {
            return "No Data Found";
        }
    }
}
